/* individual-properties.c generated by valac 0.21.1.1-0d6f, the Vala compiler
 * generated from individual-properties.vala, do not modify */

/*
 * Copyright (C) 2011 Collabora Ltd.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authors: Travis Reitter <travis.reitter@collabora.co.uk>
 */

#include <glib.h>
#include <glib-object.h>
#include <tpf-test.h>
#include <gee.h>
#include <stdlib.h>
#include <string.h>
#include <folks-test.h>
#include <folks/folks.h>
#include <folks/folks-telepathy.h>
#include <telepathy-glib/telepathy-glib.h>
#include <tp-test-contactlist.h>
#include <gio/gio.h>


#define TYPE_INDIVIDUAL_PROPERTIES_TESTS (individual_properties_tests_get_type ())
#define INDIVIDUAL_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTests))
#define INDIVIDUAL_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsClass))
#define IS_INDIVIDUAL_PROPERTIES_TESTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS))
#define IS_INDIVIDUAL_PROPERTIES_TESTS_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_INDIVIDUAL_PROPERTIES_TESTS))
#define INDIVIDUAL_PROPERTIES_TESTS_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsClass))

typedef struct _IndividualPropertiesTests IndividualPropertiesTests;
typedef struct _IndividualPropertiesTestsClass IndividualPropertiesTestsClass;
typedef struct _IndividualPropertiesTestsPrivate IndividualPropertiesTestsPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_main_loop_unref0(var) ((var == NULL) ? NULL : (var = (g_main_loop_unref (var), NULL)))
typedef struct _Block1Data Block1Data;
typedef struct _Block2Data Block2Data;
#define _g_free0(var) (var = (g_free (var), NULL))
typedef struct _Block3Data Block3Data;
typedef struct _Block4Data Block4Data;
typedef struct _Block5Data Block5Data;
#define _g_date_time_unref0(var) ((var == NULL) ? NULL : (var = (g_date_time_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData;
#define _vala_assert(expr, msg) if G_LIKELY (expr) ; else g_assertion_message_expr (G_LOG_DOMAIN, __FILE__, __LINE__, G_STRFUNC, msg);

struct _IndividualPropertiesTests {
	TpfTestTestCase parent_instance;
	IndividualPropertiesTestsPrivate * priv;
};

struct _IndividualPropertiesTestsClass {
	TpfTestTestCaseClass parent_class;
};

struct _IndividualPropertiesTestsPrivate {
	GeeHashSet* _changes_pending;
};

struct _Block1Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	gboolean alias_notified;
};

struct _Block2Data {
	int _ref_count_;
	Block1Data * _data1_;
	gchar* new_alias;
};

struct _Block3Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	gboolean alias_notified;
};

struct _Block4Data {
	int _ref_count_;
	Block3Data * _data3_;
	gchar* new_alias;
};

struct _Block5Data {
	int _ref_count_;
	IndividualPropertiesTests * self;
	GDateTime* new_birthday;
	FolksEmailFieldDetails* new_email_fd;
	FolksPhoneFieldDetails* new_phone_fd;
	FolksUrlFieldDetails* new_url_fd;
	gchar* new_full_name;
	gpointer _async_data_;
};

struct _IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	IndividualPropertiesTests* self;
	GeeMultiMap* changes;
	Block5Data* _data5_;
	GeeCollection* added;
	GeeMultiMap* _tmp0_;
	GeeCollection* _tmp1_;
	GeeSet* removed;
	GeeMultiMap* _tmp2_;
	GeeSet* _tmp3_;
	GTimeVal timeval;
	GTimeVal _tmp4_;
	GDateTime* _tmp5_;
	FolksEmailFieldDetails* _tmp6_;
	FolksEmailFieldDetails* _tmp7_;
	FolksPhoneFieldDetails* _tmp8_;
	FolksPhoneFieldDetails* _tmp9_;
	FolksUrlFieldDetails* _tmp10_;
	FolksUrlFieldDetails* _tmp11_;
	gchar* _tmp12_;
	GeeIterator* _i_it;
	GeeCollection* _tmp13_;
	GeeIterator* _tmp14_;
	GeeIterator* _tmp15_;
	gboolean _tmp16_;
	FolksIndividual* i;
	GeeIterator* _tmp17_;
	gpointer _tmp18_;
	FolksIndividual* _tmp19_;
	gboolean _tmp20_;
	FolksIndividual* _tmp21_;
	GDateTime* _tmp22_;
	GDateTime* _tmp23_;
	GDateTime* _tmp24_;
	FolksIndividual* _tmp25_;
	GDateTime* _tmp26_;
	GDateTime* _tmp27_;
	gboolean _tmp28_;
	gboolean _tmp29_;
	FolksIndividual* _tmp30_;
	GeeSet* _tmp31_;
	GeeSet* _tmp32_;
	FolksEmailFieldDetails* _tmp33_;
	gboolean _tmp34_;
	const gchar* _tmp35_;
	FolksIndividual* _tmp36_;
	const gchar* _tmp37_;
	const gchar* _tmp38_;
	FolksIndividual* _tmp39_;
	GeeSet* _tmp40_;
	GeeSet* _tmp41_;
	FolksPhoneFieldDetails* _tmp42_;
	gboolean _tmp43_;
	FolksIndividual* _tmp44_;
	GeeSet* _tmp45_;
	GeeSet* _tmp46_;
	FolksUrlFieldDetails* _tmp47_;
	gboolean _tmp48_;
	FolksIndividual* _tmp49_;
	FolksIndividual* _tmp50_;
	FolksIndividual* _tmp51_;
	FolksIndividual* _tmp52_;
	FolksIndividual* _tmp53_;
	FolksPersona* persona;
	GeeIterator* _p_it;
	FolksIndividual* _tmp54_;
	GeeSet* _tmp55_;
	GeeSet* _tmp56_;
	GeeIterator* _tmp57_;
	GeeIterator* _tmp58_;
	gboolean _tmp59_;
	FolksPersona* p;
	GeeIterator* _tmp60_;
	gpointer _tmp61_;
	FolksPersona* _tmp62_;
	FolksPersona* _tmp63_;
	FolksPersona* _tmp64_;
	GeeHashSet* emails;
	GeeHashSet* _tmp65_;
	GeeHashSet* _tmp66_;
	FolksEmailFieldDetails* _tmp67_;
	GeeHashSet* phones;
	GeeHashSet* _tmp68_;
	GeeHashSet* _tmp69_;
	FolksPhoneFieldDetails* _tmp70_;
	GeeHashSet* urls;
	GeeHashSet* _tmp71_;
	GeeHashSet* _tmp72_;
	FolksUrlFieldDetails* _tmp73_;
	gint uncaught_errors;
	FolksIndividual* _tmp74_;
	gboolean _tmp75_;
	gboolean _tmp76_;
	gint _tmp77_;
	FolksPersona* _tmp78_;
	GDateTime* _tmp79_;
	GError* e_birthday;
	FolksIndividual* _tmp80_;
	gboolean _tmp81_;
	gboolean _tmp82_;
	gint _tmp83_;
	FolksIndividual* _tmp84_;
	gboolean _tmp85_;
	gboolean _tmp86_;
	gint _tmp87_;
	FolksPersona* _tmp88_;
	GeeHashSet* _tmp89_;
	GError* e0;
	FolksIndividual* _tmp90_;
	gboolean _tmp91_;
	gboolean _tmp92_;
	gint _tmp93_;
	FolksIndividual* _tmp94_;
	gboolean _tmp95_;
	gboolean _tmp96_;
	gint _tmp97_;
	FolksPersona* _tmp98_;
	const gchar* _tmp99_;
	GError* e1;
	FolksIndividual* _tmp100_;
	gboolean _tmp101_;
	gboolean _tmp102_;
	gint _tmp103_;
	FolksIndividual* _tmp104_;
	gboolean _tmp105_;
	gboolean _tmp106_;
	gint _tmp107_;
	FolksPersona* _tmp108_;
	GeeHashSet* _tmp109_;
	GError* e2;
	FolksIndividual* _tmp110_;
	gboolean _tmp111_;
	gboolean _tmp112_;
	gint _tmp113_;
	FolksIndividual* _tmp114_;
	gboolean _tmp115_;
	gboolean _tmp116_;
	gint _tmp117_;
	FolksPersona* _tmp118_;
	GeeHashSet* _tmp119_;
	GError* e3;
	FolksIndividual* _tmp120_;
	gboolean _tmp121_;
	gboolean _tmp122_;
	gint _tmp123_;
	FolksIndividual* _tmp124_;
	gboolean _tmp125_;
	gboolean _tmp126_;
	gint _tmp127_;
	GeeSet* _tmp128_;
	gint _tmp129_;
	gint _tmp130_;
	GeeIterator* _r_it;
	GeeSet* _tmp131_;
	GeeIterator* _tmp132_;
	GeeIterator* _tmp133_;
	gboolean _tmp134_;
	FolksIndividual* r;
	GeeIterator* _tmp135_;
	gpointer _tmp136_;
	FolksIndividual* _tmp137_;
	GError * _inner_error_;
};


static gpointer individual_properties_tests_parent_class = NULL;

GType individual_properties_tests_get_type (void) G_GNUC_CONST;
#define INDIVIDUAL_PROPERTIES_TESTS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTestsPrivate))
enum  {
	INDIVIDUAL_PROPERTIES_TESTS_DUMMY_PROPERTY
};
IndividualPropertiesTests* individual_properties_tests_new (void);
IndividualPropertiesTests* individual_properties_tests_construct (GType object_type);
void individual_properties_tests_test_individual_properties (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_alias_through_test_cm (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method (gpointer self);
void individual_properties_tests_test_individual_properties_change_contact_info (IndividualPropertiesTests* self);
static void _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method (gpointer self);
static void individual_properties_tests_real_set_up (FolksTestCase* base);
static void individual_properties_tests_real_tear_down (FolksTestCase* base);
static void __lambda2_ (IndividualPropertiesTests* self, GeeMultiMap* changes);
static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle);
static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes);
static Block2Data* block2_data_ref (Block2Data* _data2_);
static void block2_data_unref (void * _userdata_);
static void ____lambda4_ (Block2Data* _data2_, GObject* s, GParamSpec* p);
static void _____lambda4__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static Block3Data* block3_data_ref (Block3Data* _data3_);
static void block3_data_unref (void * _userdata_);
static void __lambda5_ (Block3Data* _data3_, GeeMultiMap* changes);
static Block4Data* block4_data_ref (Block4Data* _data4_);
static void block4_data_unref (void * _userdata_);
static void ____lambda6_ (Block4Data* _data4_, GObject* s, GParamSpec* p);
static void _____lambda6__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ___lambda5__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void __lambda7_ (IndividualPropertiesTests* self, GeeMultiMap* changes);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added (IndividualPropertiesTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_finish (IndividualPropertiesTests* self, GAsyncResult* _res_);
static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free (gpointer _data);
static gboolean _individual_properties_tests_change_contact_info_aggregator_individuals_added_co (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_);
static Block5Data* block5_data_ref (Block5Data* _data5_);
static void block5_data_unref (void * _userdata_);
static void ____lambda8_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda9_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda10_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda11_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void ____lambda12_ (Block5Data* _data5_, GObject* s, GParamSpec* p);
static void _____lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self);
static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self);
static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void individual_properties_tests_finalize (GObject* obj);
gint _vala_main (gchar** args, int args_length1);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static void _individual_properties_tests_test_individual_properties_folks_test_case_test_method (gpointer self) {
#line 35 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties (self);
#line 346 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method (gpointer self) {
#line 37 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (self);
#line 353 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method (gpointer self) {
#line 39 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_alias_through_test_cm (self);
#line 360 "individual-properties.c"
}


static void _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method (gpointer self) {
#line 41 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_test_individual_properties_change_contact_info (self);
#line 367 "individual-properties.c"
}


IndividualPropertiesTests* individual_properties_tests_construct (GType object_type) {
	IndividualPropertiesTests * self = NULL;
#line 33 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) tpf_test_test_case_construct (object_type, "IndividualProperties");
#line 35 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties", _individual_properties_tests_test_individual_properties_folks_test_case_test_method, self);
#line 37 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change alias through tp backend", _individual_properties_tests_test_individual_properties_change_alias_through_tp_backend_folks_test_case_test_method, self);
#line 39 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change alias through test cm", _individual_properties_tests_test_individual_properties_change_alias_through_test_cm_folks_test_case_test_method, self);
#line 41 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_add_test ((FolksTestCase*) self, "individual properties:change contact info", _individual_properties_tests_test_individual_properties_change_contact_info_folks_test_case_test_method, self);
#line 31 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return self;
#line 385 "individual-properties.c"
}


IndividualPropertiesTests* individual_properties_tests_new (void) {
#line 31 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return individual_properties_tests_construct (TYPE_INDIVIDUAL_PROPERTIES_TESTS);
#line 392 "individual-properties.c"
}


static void individual_properties_tests_real_set_up (FolksTestCase* base) {
	IndividualPropertiesTests * self;
	GeeHashSet* _tmp0_ = NULL;
#line 45 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) base;
#line 47 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (individual_properties_tests_parent_class)->set_up ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TPF_TEST_TYPE_TEST_CASE, TpfTestTestCase));
#line 49 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = gee_hash_set_new (G_TYPE_STRING, (GBoxedCopyFunc) g_strdup, g_free, NULL, NULL, NULL, NULL, NULL, NULL);
#line 49 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 49 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = _tmp0_;
#line 409 "individual-properties.c"
}


static void individual_properties_tests_real_tear_down (FolksTestCase* base) {
	IndividualPropertiesTests * self;
#line 52 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = (IndividualPropertiesTests*) base;
#line 54 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 54 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = NULL;
#line 56 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (individual_properties_tests_parent_class)->tear_down ((FolksTestCase*) G_TYPE_CHECK_INSTANCE_CAST (self, TPF_TEST_TYPE_TEST_CASE, TpfTestTestCase));
#line 423 "individual-properties.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 93 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return self ? g_object_ref (self) : NULL;
#line 430 "individual-properties.c"
}


static gboolean _vala_string_array_contains (gchar** stack, int stack_length, gchar* needle) {
	int i;
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	for (i = 0; i < stack_length; i++) {
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		if (g_strcmp0 (stack[i], needle) == 0) {
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			return TRUE;
#line 442 "individual-properties.c"
		}
	}
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return FALSE;
#line 447 "individual-properties.c"
}


static void __lambda2_ (IndividualPropertiesTests* self, GeeMultiMap* changes) {
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp170_ = NULL;
	gint _tmp171_ = 0;
	gint _tmp172_ = 0;
#line 65 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 67 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 67 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 67 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 68 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 68 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 68 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 475 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp4_ = NULL;
		GeeIterator* _tmp5_ = NULL;
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp4_ = added;
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = gee_iterable_iterator ((GeeIterable*) _tmp4_);
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp5_;
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 488 "individual-properties.c"
			GeeIterator* _tmp6_ = NULL;
			gboolean _tmp7_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp8_ = NULL;
			gpointer _tmp9_ = NULL;
			FolksIndividual* _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			gboolean _tmp13_ = FALSE;
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp6_ = _i_it;
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = gee_iterator_next (_tmp6_);
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp7_) {
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 506 "individual-properties.c"
			}
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = _i_it;
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = gee_iterator_get (_tmp8_);
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp9_;
#line 72 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = i;
#line 72 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp10_ != NULL, "i != null");
#line 75 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 75 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = folks_individual_get_is_user (_tmp11_);
#line 75 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = _tmp12_;
#line 75 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_tmp13_) {
#line 526 "individual-properties.c"
				FolksIndividual* _tmp14_ = NULL;
				const gchar* _tmp15_ = NULL;
				const gchar* _tmp16_ = NULL;
				FolksIndividual* _tmp17_ = NULL;
				const gchar* _tmp18_ = NULL;
				const gchar* _tmp19_ = NULL;
				FolksIndividual* _tmp20_ = NULL;
				const gchar* _tmp21_ = NULL;
				const gchar* _tmp22_ = NULL;
				FolksIndividual* _tmp23_ = NULL;
				FolksPresenceType _tmp24_ = 0;
				FolksPresenceType _tmp25_ = 0;
				FolksIndividual* _tmp26_ = NULL;
				gboolean _tmp27_ = FALSE;
				FolksIndividual* _tmp28_ = NULL;
				GeeSet* _tmp29_ = NULL;
				GeeSet* _tmp30_ = NULL;
				gint _tmp31_ = 0;
				gint _tmp32_ = 0;
				TpfPersona* tpf_persona = NULL;
				TpfPersona* _tmp44_ = NULL;
				TpfPersona* _tmp45_ = NULL;
				gchar** _tmp46_ = NULL;
				gint _tmp46__length1 = 0;
				gchar** _tmp47_ = NULL;
				gint _tmp47__length1 = 0;
				TpfPersona* _tmp48_ = NULL;
				gchar** _tmp49_ = NULL;
				gint _tmp49__length1 = 0;
				gchar** _tmp50_ = NULL;
				gint _tmp50__length1 = 0;
				TpfPersona* _tmp51_ = NULL;
				gchar** _tmp52_ = NULL;
				gint _tmp52__length1 = 0;
				gchar** _tmp53_ = NULL;
				gint _tmp53__length1 = 0;
				TpfPersona* _tmp54_ = NULL;
				gboolean _tmp55_ = FALSE;
				gboolean _tmp56_ = FALSE;
				TpfPersona* _tmp57_ = NULL;
				gchar** _tmp58_ = NULL;
				gint _tmp58__length1 = 0;
				gchar** _tmp59_ = NULL;
				gint _tmp59__length1 = 0;
				TpfPersona* _tmp60_ = NULL;
				gchar** _tmp61_ = NULL;
				gint _tmp61__length1 = 0;
				gchar** _tmp62_ = NULL;
				gint _tmp62__length1 = 0;
				TpfPersona* _tmp63_ = NULL;
				gchar** _tmp64_ = NULL;
				gint _tmp64__length1 = 0;
				gchar** _tmp65_ = NULL;
				gint _tmp65__length1 = 0;
				TpfPersona* _tmp66_ = NULL;
				gchar** _tmp67_ = NULL;
				gint _tmp67__length1 = 0;
				gchar** _tmp68_ = NULL;
				gint _tmp68__length1 = 0;
				TpfPersona* _tmp69_ = NULL;
				gchar** _tmp70_ = NULL;
				gint _tmp70__length1 = 0;
				gchar** _tmp71_ = NULL;
				gint _tmp71__length1 = 0;
				FolksIndividual* _tmp72_ = NULL;
				const gchar* _tmp73_ = NULL;
				const gchar* _tmp74_ = NULL;
				FolksIndividual* _tmp75_ = NULL;
				GeeSet* _tmp76_ = NULL;
				GeeSet* _tmp77_ = NULL;
				gint _tmp78_ = 0;
				gint _tmp79_ = 0;
#line 78 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp14_ = i;
#line 78 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp15_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp14_);
#line 78 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp16_ = _tmp15_;
#line 78 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp16_, "me@example.com") == 0, "i.alias == \"me@example.com\"");
#line 79 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp17_ = i;
#line 79 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp18_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) _tmp17_);
#line 79 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp19_ = _tmp18_;
#line 79 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp19_, "") == 0, "i.presence_message == \"\"");
#line 80 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 80 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) _tmp20_);
#line 80 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 80 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp22_, "available") == 0, "i.presence_status == \"available\"");
#line 81 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = i;
#line 81 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp24_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp23_);
#line 81 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp25_ = _tmp24_;
#line 81 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp25_ == FOLKS_PRESENCE_TYPE_AVAILABLE, "i.presence_type == PresenceType.AVAILABLE");
#line 82 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp26_ = i;
#line 82 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp27_ = folks_presence_details_is_online (G_TYPE_CHECK_INSTANCE_CAST (_tmp26_, FOLKS_TYPE_PRESENCE_DETAILS, FolksPresenceDetails));
#line 82 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp27_ == TRUE, "((PresenceDetails) i).is_online () == true");
#line 85 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp28_ = i;
#line 85 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp29_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp28_);
#line 85 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp30_ = _tmp29_;
#line 85 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp31_ = gee_collection_get_size ((GeeCollection*) _tmp30_);
#line 85 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp32_ = _tmp31_;
#line 85 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp32_ == 0, "i.groups.size == 0");
#line 88 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				tpf_persona = NULL;
#line 651 "individual-properties.c"
				{
					GeeIterator* _p_it = NULL;
					FolksIndividual* _tmp33_ = NULL;
					GeeSet* _tmp34_ = NULL;
					GeeSet* _tmp35_ = NULL;
					GeeIterator* _tmp36_ = NULL;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp33_ = i;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp34_ = folks_individual_get_personas (_tmp33_);
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp35_ = _tmp34_;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp36_ = gee_iterable_iterator ((GeeIterable*) _tmp35_);
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_p_it = _tmp36_;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					while (TRUE) {
#line 670 "individual-properties.c"
						GeeIterator* _tmp37_ = NULL;
						gboolean _tmp38_ = FALSE;
						FolksPersona* p = NULL;
						GeeIterator* _tmp39_ = NULL;
						gpointer _tmp40_ = NULL;
						FolksPersona* _tmp41_ = NULL;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp37_ = _p_it;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp38_ = gee_iterator_next (_tmp37_);
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						if (!_tmp38_) {
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							break;
#line 685 "individual-properties.c"
						}
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp39_ = _p_it;
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp40_ = gee_iterator_get (_tmp39_);
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						p = (FolksPersona*) _tmp40_;
#line 91 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp41_ = p;
#line 91 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp41_, TPF_TYPE_PERSONA)) {
#line 697 "individual-properties.c"
							FolksPersona* _tmp42_ = NULL;
							TpfPersona* _tmp43_ = NULL;
#line 93 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp42_ = p;
#line 93 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp43_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp42_, TPF_TYPE_PERSONA) ? ((TpfPersona*) _tmp42_) : NULL);
#line 93 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (tpf_persona);
#line 93 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							tpf_persona = _tmp43_;
#line 94 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (p);
#line 94 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							break;
#line 712 "individual-properties.c"
						}
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_g_object_unref0 (p);
#line 716 "individual-properties.c"
					}
#line 89 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_p_it);
#line 720 "individual-properties.c"
				}
#line 97 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp44_ = tpf_persona;
#line 97 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp44_ != NULL, "tpf_persona != null");
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp45_ = tpf_persona;
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp46_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp45_, &_tmp46__length1);
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp47_ = _tmp46_;
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp47__length1 = _tmp46__length1;
#line 98 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp47_, _tmp47__length1, "alias"), "\"alias\" in tpf_persona.writeable_properties");
#line 100 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp48_ = tpf_persona;
#line 100 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp49_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp48_, &_tmp49__length1);
#line 100 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp50_ = _tmp49_;
#line 100 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp50__length1 = _tmp49__length1;
#line 100 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (!_vala_string_array_contains (_tmp50_, _tmp50__length1, "is-favourite"), "!(\"is-favourite\"                        in tpf_persona.writeable_properties)");
#line 102 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp51_ = tpf_persona;
#line 102 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp52_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp51_, &_tmp52__length1);
#line 102 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp53_ = _tmp52_;
#line 102 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp53__length1 = _tmp52__length1;
#line 102 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp53_, _tmp53__length1, "groups"), "\"groups\" in tpf_persona.writeable_properties");
#line 104 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp54_ = tpf_persona;
#line 104 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp55_ = folks_persona_get_is_user ((FolksPersona*) _tmp54_);
#line 104 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp56_ = _tmp55_;
#line 104 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp56_, "tpf_persona.is_user");
#line 105 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp57_ = tpf_persona;
#line 105 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp58_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp57_, &_tmp58__length1);
#line 105 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp59_ = _tmp58_;
#line 105 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp59__length1 = _tmp58__length1;
#line 105 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp59_, _tmp59__length1, "birthday"), "\"birthday\" in tpf_persona.writeable_properties");
#line 106 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp60_ = tpf_persona;
#line 106 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp61_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp60_, &_tmp61__length1);
#line 106 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp62_ = _tmp61_;
#line 106 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp62__length1 = _tmp61__length1;
#line 106 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp62_, _tmp62__length1, "email-addresses"), "\"email-addresses\" in tpf_persona.writeable_properties");
#line 108 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp63_ = tpf_persona;
#line 108 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp64_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp63_, &_tmp64__length1);
#line 108 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp65_ = _tmp64_;
#line 108 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp65__length1 = _tmp64__length1;
#line 108 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp65_, _tmp65__length1, "full-name"), "\"full-name\" in tpf_persona.writeable_properties");
#line 109 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp66_ = tpf_persona;
#line 109 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp67_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp66_, &_tmp67__length1);
#line 109 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp68_ = _tmp67_;
#line 109 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp68__length1 = _tmp67__length1;
#line 109 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp68_, _tmp68__length1, "phone-numbers"), "\"phone-numbers\" in tpf_persona.writeable_properties");
#line 111 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp69_ = tpf_persona;
#line 111 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp70_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp69_, &_tmp70__length1);
#line 111 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp71_ = _tmp70_;
#line 111 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp71__length1 = _tmp70__length1;
#line 111 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_vala_string_array_contains (_tmp71_, _tmp71__length1, "urls"), "\"urls\" in tpf_persona.writeable_properties");
#line 114 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp72_ = i;
#line 114 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp73_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp72_);
#line 114 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp74_ = _tmp73_;
#line 114 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (g_strcmp0 (_tmp74_, "") == 0, "i.full_name == \"\"");
#line 115 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp75_ = i;
#line 115 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp76_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp75_);
#line 115 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp77_ = _tmp76_;
#line 115 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp78_ = gee_collection_get_size ((GeeCollection*) _tmp77_);
#line 115 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp79_ = _tmp78_;
#line 115 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_tmp79_ == 0, "i.phone_numbers.size == 0");
#line 75 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (tpf_persona);
#line 836 "individual-properties.c"
			} else {
				FolksIndividual* _tmp80_ = NULL;
				const gchar* _tmp81_ = NULL;
				const gchar* _tmp82_ = NULL;
#line 120 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp80_ = i;
#line 120 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp81_ = folks_individual_get_id (_tmp80_);
#line 120 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp82_ = _tmp81_;
#line 120 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (g_strcmp0 (_tmp82_, "0e46c5e74f61908f49550d241f2a1651892a1695") == 0) {
#line 849 "individual-properties.c"
					FolksIndividual* _tmp83_ = NULL;
					const gchar* _tmp84_ = NULL;
					const gchar* _tmp85_ = NULL;
					FolksIndividual* _tmp86_ = NULL;
					const gchar* _tmp87_ = NULL;
					const gchar* _tmp88_ = NULL;
					FolksIndividual* _tmp89_ = NULL;
					const gchar* _tmp90_ = NULL;
					const gchar* _tmp91_ = NULL;
					FolksIndividual* _tmp92_ = NULL;
					FolksPresenceType _tmp93_ = 0;
					FolksPresenceType _tmp94_ = 0;
					FolksIndividual* _tmp95_ = NULL;
					gboolean _tmp96_ = FALSE;
					FolksIndividual* _tmp97_ = NULL;
					GeeSet* _tmp98_ = NULL;
					GeeSet* _tmp99_ = NULL;
					gint _tmp100_ = 0;
					gint _tmp101_ = 0;
					FolksIndividual* _tmp102_ = NULL;
					GeeSet* _tmp103_ = NULL;
					GeeSet* _tmp104_ = NULL;
					gboolean _tmp105_ = FALSE;
					FolksIndividual* _tmp106_ = NULL;
					GeeSet* _tmp107_ = NULL;
					GeeSet* _tmp108_ = NULL;
					gboolean _tmp109_ = FALSE;
					TpfPersona* tpf_persona = NULL;
					TpfPersona* _tmp121_ = NULL;
					TpfPersona* _tmp122_ = NULL;
					gchar** _tmp123_ = NULL;
					gint _tmp123__length1 = 0;
					gchar** _tmp124_ = NULL;
					gint _tmp124__length1 = 0;
					TpfPersona* _tmp125_ = NULL;
					gchar** _tmp126_ = NULL;
					gint _tmp126__length1 = 0;
					gchar** _tmp127_ = NULL;
					gint _tmp127__length1 = 0;
					TpfPersona* _tmp128_ = NULL;
					gchar** _tmp129_ = NULL;
					gint _tmp129__length1 = 0;
					gchar** _tmp130_ = NULL;
					gint _tmp130__length1 = 0;
					TpfPersona* _tmp131_ = NULL;
					gboolean _tmp132_ = FALSE;
					gboolean _tmp133_ = FALSE;
					TpfPersona* _tmp134_ = NULL;
					gchar** _tmp135_ = NULL;
					gint _tmp135__length1 = 0;
					gchar** _tmp136_ = NULL;
					gint _tmp136__length1 = 0;
					TpfPersona* _tmp137_ = NULL;
					gchar** _tmp138_ = NULL;
					gint _tmp138__length1 = 0;
					gchar** _tmp139_ = NULL;
					gint _tmp139__length1 = 0;
					TpfPersona* _tmp140_ = NULL;
					gchar** _tmp141_ = NULL;
					gint _tmp141__length1 = 0;
					gchar** _tmp142_ = NULL;
					gint _tmp142__length1 = 0;
					TpfPersona* _tmp143_ = NULL;
					gchar** _tmp144_ = NULL;
					gint _tmp144__length1 = 0;
					gchar** _tmp145_ = NULL;
					gint _tmp145__length1 = 0;
					TpfPersona* _tmp146_ = NULL;
					gchar** _tmp147_ = NULL;
					gint _tmp147__length1 = 0;
					gchar** _tmp148_ = NULL;
					gint _tmp148__length1 = 0;
					FolksIndividual* _tmp149_ = NULL;
					GeeSet* _tmp150_ = NULL;
					GeeSet* _tmp151_ = NULL;
					FolksPhoneFieldDetails* _tmp152_ = NULL;
					FolksPhoneFieldDetails* _tmp153_ = NULL;
					gboolean _tmp154_ = FALSE;
					FolksIndividual* _tmp155_ = NULL;
					const gchar* _tmp156_ = NULL;
					const gchar* _tmp157_ = NULL;
					FolksIndividual* _tmp158_ = NULL;
					GeeSet* _tmp159_ = NULL;
					GeeSet* _tmp160_ = NULL;
					FolksEmailFieldDetails* _tmp161_ = NULL;
					FolksEmailFieldDetails* _tmp162_ = NULL;
					gboolean _tmp163_ = FALSE;
					FolksIndividual* _tmp164_ = NULL;
					GeeSet* _tmp165_ = NULL;
					GeeSet* _tmp166_ = NULL;
					FolksUrlFieldDetails* _tmp167_ = NULL;
					FolksUrlFieldDetails* _tmp168_ = NULL;
					gboolean _tmp169_ = FALSE;
#line 123 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp83_ = i;
#line 123 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp84_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp83_);
#line 123 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp85_ = _tmp84_;
#line 123 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp85_, "Olivier") == 0, "i.alias == \"Olivier\"");
#line 124 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp86_ = i;
#line 124 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp87_ = folks_presence_details_get_presence_message ((FolksPresenceDetails*) _tmp86_);
#line 124 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp88_ = _tmp87_;
#line 124 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp88_, "") == 0, "i.presence_message == \"\"");
#line 125 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp89_ = i;
#line 125 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp90_ = folks_presence_details_get_presence_status ((FolksPresenceDetails*) _tmp89_);
#line 125 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp91_ = _tmp90_;
#line 125 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp91_, "away") == 0, "i.presence_status == \"away\"");
#line 126 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp92_ = i;
#line 126 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp93_ = folks_presence_details_get_presence_type ((FolksPresenceDetails*) _tmp92_);
#line 126 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp94_ = _tmp93_;
#line 126 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp94_ == FOLKS_PRESENCE_TYPE_AWAY, "i.presence_type == PresenceType.AWAY");
#line 127 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp95_ = i;
#line 127 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp96_ = folks_presence_details_is_online (G_TYPE_CHECK_INSTANCE_CAST (_tmp95_, FOLKS_TYPE_PRESENCE_DETAILS, FolksPresenceDetails));
#line 127 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp96_ == TRUE, "((PresenceDetails) i).is_online () == true");
#line 130 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp97_ = i;
#line 130 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp98_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp97_);
#line 130 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp99_ = _tmp98_;
#line 130 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp100_ = gee_collection_get_size ((GeeCollection*) _tmp99_);
#line 130 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp101_ = _tmp100_;
#line 130 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp101_ == 2, "i.groups.size == 2");
#line 131 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp102_ = i;
#line 131 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp103_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp102_);
#line 131 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp104_ = _tmp103_;
#line 131 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp105_ = gee_collection_contains ((GeeCollection*) _tmp104_, "Montreal");
#line 131 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp105_ == TRUE, "i.groups.contains (\"Montreal\") == true");
#line 132 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp106_ = i;
#line 132 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp107_ = folks_group_details_get_groups ((FolksGroupDetails*) _tmp106_);
#line 132 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp108_ = _tmp107_;
#line 132 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp109_ = gee_collection_contains ((GeeCollection*) _tmp108_, "Francophones");
#line 132 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp109_ == TRUE, "i.groups.contains (\"Francophones\") == true");
#line 135 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					tpf_persona = NULL;
#line 1015 "individual-properties.c"
					{
						GeeIterator* _p_it = NULL;
						FolksIndividual* _tmp110_ = NULL;
						GeeSet* _tmp111_ = NULL;
						GeeSet* _tmp112_ = NULL;
						GeeIterator* _tmp113_ = NULL;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp110_ = i;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp111_ = folks_individual_get_personas (_tmp110_);
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp112_ = _tmp111_;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_tmp113_ = gee_iterable_iterator ((GeeIterable*) _tmp112_);
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_p_it = _tmp113_;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						while (TRUE) {
#line 1034 "individual-properties.c"
							GeeIterator* _tmp114_ = NULL;
							gboolean _tmp115_ = FALSE;
							FolksPersona* p = NULL;
							GeeIterator* _tmp116_ = NULL;
							gpointer _tmp117_ = NULL;
							FolksPersona* _tmp118_ = NULL;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp114_ = _p_it;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp115_ = gee_iterator_next (_tmp114_);
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							if (!_tmp115_) {
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								break;
#line 1049 "individual-properties.c"
							}
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp116_ = _p_it;
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp117_ = gee_iterator_get (_tmp116_);
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							p = (FolksPersona*) _tmp117_;
#line 138 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_tmp118_ = p;
#line 138 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp118_, TPF_TYPE_PERSONA)) {
#line 1061 "individual-properties.c"
								FolksPersona* _tmp119_ = NULL;
								TpfPersona* _tmp120_ = NULL;
#line 140 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								_tmp119_ = p;
#line 140 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								_tmp120_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp119_, TPF_TYPE_PERSONA) ? ((TpfPersona*) _tmp119_) : NULL);
#line 140 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								_g_object_unref0 (tpf_persona);
#line 140 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								tpf_persona = _tmp120_;
#line 141 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								_g_object_unref0 (p);
#line 141 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
								break;
#line 1076 "individual-properties.c"
							}
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
							_g_object_unref0 (p);
#line 1080 "individual-properties.c"
						}
#line 136 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						_g_object_unref0 (_p_it);
#line 1084 "individual-properties.c"
					}
#line 144 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp121_ = tpf_persona;
#line 144 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp121_ != NULL, "tpf_persona != null");
#line 145 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp122_ = tpf_persona;
#line 145 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp123_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp122_, &_tmp123__length1);
#line 145 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp124_ = _tmp123_;
#line 145 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp124__length1 = _tmp123__length1;
#line 145 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_vala_string_array_contains (_tmp124_, _tmp124__length1, "alias"), "\"alias\" in tpf_persona.writeable_properties");
#line 147 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp125_ = tpf_persona;
#line 147 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp126_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp125_, &_tmp126__length1);
#line 147 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp127_ = _tmp126_;
#line 147 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp127__length1 = _tmp126__length1;
#line 147 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp127_, _tmp127__length1, "is-favourite"), "!(\"is-favourite\"                       in tpf_persona.writeable_properties)");
#line 149 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp128_ = tpf_persona;
#line 149 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp129_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp128_, &_tmp129__length1);
#line 149 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp130_ = _tmp129_;
#line 149 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp130__length1 = _tmp129__length1;
#line 149 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_vala_string_array_contains (_tmp130_, _tmp130__length1, "groups"), "\"groups\" in tpf_persona.writeable_properties");
#line 151 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp131_ = tpf_persona;
#line 151 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp132_ = folks_persona_get_is_user ((FolksPersona*) _tmp131_);
#line 151 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp133_ = _tmp132_;
#line 151 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_tmp133_, "!tpf_persona.is_user");
#line 152 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp134_ = tpf_persona;
#line 152 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp135_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp134_, &_tmp135__length1);
#line 152 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp136_ = _tmp135_;
#line 152 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp136__length1 = _tmp135__length1;
#line 152 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp136_, _tmp136__length1, "birthday"), "!(\"birthday\" in tpf_persona.writeable_properties)");
#line 153 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp137_ = tpf_persona;
#line 153 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp138_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp137_, &_tmp138__length1);
#line 153 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp139_ = _tmp138_;
#line 153 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp139__length1 = _tmp138__length1;
#line 153 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp139_, _tmp139__length1, "email-addresses"), "!(\"email-addresses\" in tpf_persona.writeable_properties)");
#line 155 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp140_ = tpf_persona;
#line 155 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp141_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp140_, &_tmp141__length1);
#line 155 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp142_ = _tmp141_;
#line 155 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp142__length1 = _tmp141__length1;
#line 155 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp142_, _tmp142__length1, "full-name"), "!(\"full-name\" in tpf_persona.writeable_properties)");
#line 156 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp143_ = tpf_persona;
#line 156 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp144_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp143_, &_tmp144__length1);
#line 156 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp145_ = _tmp144_;
#line 156 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp145__length1 = _tmp144__length1;
#line 156 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp145_, _tmp145__length1, "phone-numbers"), "!(\"phone-numbers\" in tpf_persona.writeable_properties)");
#line 158 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp146_ = tpf_persona;
#line 158 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp147_ = folks_persona_get_writeable_properties ((FolksPersona*) _tmp146_, &_tmp147__length1);
#line 158 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp148_ = _tmp147_;
#line 158 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp148__length1 = _tmp147__length1;
#line 158 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (!_vala_string_array_contains (_tmp148_, _tmp148__length1, "urls"), "!(\"urls\" in tpf_persona.writeable_properties)");
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp149_ = i;
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp150_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp149_);
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp151_ = _tmp150_;
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp152_ = folks_phone_field_details_new ("+15142345678", NULL);
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp153_ = _tmp152_;
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp154_ = gee_collection_contains ((GeeCollection*) _tmp151_, _tmp153_);
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp154_, "new PhoneFieldDetails (\"+15142345678\")                       in i.phone_numbers");
#line 161 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp153_);
#line 163 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp155_ = i;
#line 163 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp156_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp155_);
#line 163 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp157_ = _tmp156_;
#line 163 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (g_strcmp0 (_tmp157_, "Olivier Crete") == 0, "i.full_name == \"Olivier Crete\"");
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp158_ = i;
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp159_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp158_);
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp160_ = _tmp159_;
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp161_ = folks_email_field_details_new ("olivier@example.com", NULL);
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp162_ = _tmp161_;
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp163_ = gee_collection_contains ((GeeCollection*) _tmp160_, _tmp162_);
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp163_, "new EmailFieldDetails (\"olivier@example.com\")                       in i.email_addresses");
#line 164 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp162_);
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp164_ = i;
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp165_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp164_);
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp166_ = _tmp165_;
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp167_ = folks_url_field_details_new ("ocrete.example.com", NULL);
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp168_ = _tmp167_;
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp169_ = gee_collection_contains ((GeeCollection*) _tmp166_, _tmp168_);
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_vala_assert (_tmp169_, "new UrlFieldDetails (\"ocrete.example.com\") in i.urls");
#line 166 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_tmp168_);
#line 120 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (tpf_persona);
#line 1236 "individual-properties.c"
				}
			}
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1241 "individual-properties.c"
		}
#line 70 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1245 "individual-properties.c"
	}
#line 170 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp170_ = removed;
#line 170 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp171_ = gee_collection_get_size ((GeeCollection*) _tmp170_);
#line 170 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp172_ = _tmp171_;
#line 170 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp172_ == 1, "removed.size == 1");
#line 1255 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp173_ = NULL;
		GeeIterator* _tmp174_ = NULL;
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp173_ = removed;
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp174_ = gee_iterable_iterator ((GeeIterable*) _tmp173_);
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp174_;
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1268 "individual-properties.c"
			GeeIterator* _tmp175_ = NULL;
			gboolean _tmp176_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp177_ = NULL;
			gpointer _tmp178_ = NULL;
			FolksIndividual* _tmp179_ = NULL;
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp175_ = _i_it;
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp176_ = gee_iterator_next (_tmp175_);
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp176_) {
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1283 "individual-properties.c"
			}
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp177_ = _i_it;
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp178_ = gee_iterator_get (_tmp177_);
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp178_;
#line 174 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp179_ = i;
#line 174 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp179_ == NULL, "i == null");
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1297 "individual-properties.c"
		}
#line 172 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1301 "individual-properties.c"
	}
#line 65 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 65 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 1307 "individual-properties.c"
}


static void ___lambda2__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 65 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	__lambda2_ (self, changes);
#line 1314 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties (IndividualPropertiesTests* self) {
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
#line 59 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 61 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 61 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 64 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_dup ();
#line 64 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 65 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 65 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_object (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda2__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 177 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 177 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 182 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 185 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 185 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 59 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 59 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 1353 "individual-properties.c"
}


static Block1Data* block1_data_ref (Block1Data* _data1_) {
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data1_->_ref_count_);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return _data1_;
#line 1362 "individual-properties.c"
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
#line 1371 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		self = _data1_->self;
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block1Data, _data1_);
#line 1379 "individual-properties.c"
	}
}


static Block2Data* block2_data_ref (Block2Data* _data2_) {
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data2_->_ref_count_);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return _data2_;
#line 1389 "individual-properties.c"
}


static void block2_data_unref (void * _userdata_) {
	Block2Data* _data2_;
	_data2_ = (Block2Data*) _userdata_;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data2_->_ref_count_)) {
#line 1398 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		self = _data2_->_data1_->self;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data2_->new_alias);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		block1_data_unref (_data2_->_data1_);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data2_->_data1_ = NULL;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block2Data, _data2_);
#line 1410 "individual-properties.c"
	}
}


static void ____lambda4_ (Block2Data* _data2_, GObject* s, GParamSpec* p) {
	Block1Data* _data1_;
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data1_ = _data2_->_data1_;
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data1_->self;
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 219 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 219 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 219 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 221 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 221 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp2_);
#line 221 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 221 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data2_->new_alias;
#line 221 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 222 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data1_->alias_notified = TRUE;
#line 1451 "individual-properties.c"
	}
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 1455 "individual-properties.c"
}


static void _____lambda4__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda4_ (self, _sender, pspec);
#line 1462 "individual-properties.c"
}


static void __lambda3_ (Block1Data* _data1_, GeeMultiMap* changes) {
	IndividualPropertiesTests * self;
	Block2Data* _data2_;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GeeSet* _tmp33_ = NULL;
	gint _tmp34_ = 0;
	gint _tmp35_ = 0;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data1_->self;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data2_ = g_slice_new0 (Block2Data);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data2_->_ref_count_ = 1;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data2_->_data1_ = block1_data_ref (_data1_);
#line 197 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 197 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 197 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 198 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 198 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 198 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 200 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = g_strdup ("New Alias");
#line 200 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data2_->new_alias = _tmp4_;
#line 1505 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = added;
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp6_;
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1518 "individual-properties.c"
			GeeIterator* _tmp7_ = NULL;
			gboolean _tmp8_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp9_ = NULL;
			gpointer _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			FolksIndividual* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			FolksIndividual* _tmp19_ = NULL;
			FolksPersona* persona = NULL;
			FolksPersona* _tmp30_ = NULL;
			FolksPersona* _tmp31_ = NULL;
			const gchar* _tmp32_ = NULL;
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = _i_it;
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp8_) {
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1545 "individual-properties.c"
			}
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = _i_it;
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp10_;
#line 204 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 204 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp11_ != NULL, "i != null");
#line 208 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = i;
#line 208 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 208 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp14_ = _tmp13_;
#line 208 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (g_strcmp0 (_tmp14_, "0e46c5e74f61908f49550d241f2a1651892a1695") != 0) {
#line 210 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (i);
#line 210 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				continue;
#line 1569 "individual-properties.c"
			}
#line 214 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp15_ = i;
#line 214 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp16_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp15_);
#line 214 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp17_ = _tmp16_;
#line 214 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp18_ = _data2_->new_alias;
#line 214 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (g_strcmp0 (_tmp17_, _tmp18_) != 0, "i.alias != new_alias");
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp19_ = i;
#line 216 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _tmp19_, "notify::alias", (GCallback) _____lambda4__g_object_notify, block2_data_ref (_data2_), (GClosureNotify) block2_data_unref, 0);
#line 227 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			persona = NULL;
#line 1587 "individual-properties.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp20_ = NULL;
				GeeSet* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeIterator* _tmp23_ = NULL;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_individual_get_personas (_tmp20_);
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_p_it = _tmp23_;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 1606 "individual-properties.c"
					GeeIterator* _tmp24_ = NULL;
					gboolean _tmp25_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp26_ = NULL;
					gpointer _tmp27_ = NULL;
					FolksPersona* _tmp28_ = NULL;
					FolksPersona* _tmp29_ = NULL;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp24_ = _p_it;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp25_ = gee_iterator_next (_tmp24_);
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (!_tmp25_) {
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						break;
#line 1622 "individual-properties.c"
					}
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp26_ = _p_it;
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp27_ = gee_iterator_get (_tmp26_);
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					p = (FolksPersona*) _tmp27_;
#line 230 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp28_ = p;
#line 230 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp29_ = _g_object_ref0 (_tmp28_);
#line 230 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (persona);
#line 230 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					persona = _tmp29_;
#line 231 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (p);
#line 231 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					break;
#line 1642 "individual-properties.c"
				}
#line 228 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_p_it);
#line 1646 "individual-properties.c"
			}
#line 233 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp30_ = persona;
#line 233 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TPF_TYPE_PERSONA), "persona is Tpf.Persona");
#line 238 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp31_ = persona;
#line 238 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp32_ = _data2_->new_alias;
#line 238 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			folks_alias_details_set_alias ((FolksAliasDetails*) G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, TPF_TYPE_PERSONA, TpfPersona), _tmp32_);
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (persona);
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1662 "individual-properties.c"
		}
#line 202 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1666 "individual-properties.c"
	}
#line 241 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp33_ = removed;
#line 241 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp34_ = gee_collection_get_size ((GeeCollection*) _tmp33_);
#line 241 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp35_ = _tmp34_;
#line 241 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp35_ == 1, "removed.size == 1");
#line 1676 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp36_ = NULL;
		GeeIterator* _tmp37_ = NULL;
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp36_ = removed;
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp37_ = gee_iterable_iterator ((GeeIterable*) _tmp36_);
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp37_;
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1689 "individual-properties.c"
			GeeIterator* _tmp38_ = NULL;
			gboolean _tmp39_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp40_ = NULL;
			gpointer _tmp41_ = NULL;
			FolksIndividual* _tmp42_ = NULL;
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp38_ = _i_it;
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp39_ = gee_iterator_next (_tmp38_);
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp39_) {
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 1704 "individual-properties.c"
			}
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp40_ = _i_it;
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp41_ = gee_iterator_get (_tmp40_);
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp41_;
#line 245 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp42_ = i;
#line 245 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp42_ == NULL, "i == null");
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 1718 "individual-properties.c"
		}
#line 243 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 1722 "individual-properties.c"
	}
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	block2_data_unref (_data2_);
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data2_ = NULL;
#line 1732 "individual-properties.c"
}


static void ___lambda3__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	__lambda3_ (self, changes);
#line 1739 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_alias_through_tp_backend (IndividualPropertiesTests* self) {
	Block1Data* _data1_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data1_ = g_slice_new0 (Block1Data);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data1_->_ref_count_ = 1;
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data1_->self = g_object_ref (self);
#line 190 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 190 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 191 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data1_->alias_notified = FALSE;
#line 194 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_dup ();
#line 194 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 195 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_data (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda3__folks_individual_aggregator_individuals_changed_detailed, block1_data_ref (_data1_), (GClosureNotify) block1_data_unref, 0);
#line 248 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 248 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 253 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 255 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data1_->alias_notified, "alias_notified");
#line 258 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 258 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	block1_data_unref (_data1_);
#line 188 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data1_ = NULL;
#line 1793 "individual-properties.c"
}


static Block3Data* block3_data_ref (Block3Data* _data3_) {
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data3_->_ref_count_);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return _data3_;
#line 1802 "individual-properties.c"
}


static void block3_data_unref (void * _userdata_) {
	Block3Data* _data3_;
	_data3_ = (Block3Data*) _userdata_;
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data3_->_ref_count_)) {
#line 1811 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		self = _data3_->self;
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block3Data, _data3_);
#line 1819 "individual-properties.c"
	}
}


static Block4Data* block4_data_ref (Block4Data* _data4_) {
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data4_->_ref_count_);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return _data4_;
#line 1829 "individual-properties.c"
}


static void block4_data_unref (void * _userdata_) {
	Block4Data* _data4_;
	_data4_ = (Block4Data*) _userdata_;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data4_->_ref_count_)) {
#line 1838 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		self = _data4_->_data3_->self;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data4_->new_alias);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		block3_data_unref (_data4_->_data3_);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data4_->_data3_ = NULL;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block4Data, _data4_);
#line 1850 "individual-properties.c"
	}
}


static void ____lambda6_ (Block4Data* _data4_, GObject* s, GParamSpec* p) {
	Block3Data* _data3_;
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data3_ = _data4_->_data3_;
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data3_->self;
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 292 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 292 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 292 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 294 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 294 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp2_);
#line 294 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 294 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data4_->new_alias;
#line 294 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 295 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data3_->alias_notified = TRUE;
#line 1891 "individual-properties.c"
	}
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 1895 "individual-properties.c"
}


static void _____lambda6__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda6_ (self, _sender, pspec);
#line 1902 "individual-properties.c"
}


static void __lambda5_ (Block3Data* _data3_, GeeMultiMap* changes) {
	IndividualPropertiesTests * self;
	Block4Data* _data4_;
	GeeCollection* added = NULL;
	GeeMultiMap* _tmp0_ = NULL;
	GeeCollection* _tmp1_ = NULL;
	GeeSet* removed = NULL;
	GeeMultiMap* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GeeSet* _tmp48_ = NULL;
	gint _tmp49_ = 0;
	gint _tmp50_ = 0;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data3_->self;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data4_ = g_slice_new0 (Block4Data);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data4_->_ref_count_ = 1;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data4_->_data3_ = block3_data_ref (_data3_);
#line 270 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 270 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = gee_multi_map_get_values (_tmp0_);
#line 270 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	added = _tmp1_;
#line 271 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = changes;
#line 271 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = gee_multi_map_get_keys (_tmp2_);
#line 271 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	removed = _tmp3_;
#line 273 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = g_strdup ("New Alias");
#line 273 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data4_->new_alias = _tmp4_;
#line 1945 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeCollection* _tmp5_ = NULL;
		GeeIterator* _tmp6_ = NULL;
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp5_ = added;
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = gee_iterable_iterator ((GeeIterable*) _tmp5_);
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp6_;
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 1958 "individual-properties.c"
			GeeIterator* _tmp7_ = NULL;
			gboolean _tmp8_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp9_ = NULL;
			gpointer _tmp10_ = NULL;
			FolksIndividual* _tmp11_ = NULL;
			FolksIndividual* _tmp12_ = NULL;
			const gchar* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			FolksIndividual* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			const gchar* _tmp18_ = NULL;
			FolksIndividual* _tmp19_ = NULL;
			FolksPersona* persona = NULL;
			FolksPersona* _tmp30_ = NULL;
			TpHandle handle = 0U;
			FolksPersona* _tmp31_ = NULL;
			TpContact* _tmp32_ = NULL;
			TpContact* _tmp33_ = NULL;
			guint _tmp34_ = 0U;
			guint _tmp35_ = 0U;
			TpTestsContactsConnection* conn = NULL;
			TpTestsBackend* _tmp36_ = NULL;
			void* _tmp37_ = NULL;
			TpTestsContactsConnection* _tmp38_ = NULL;
			TpTestsContactsConnection* _tmp39_ = NULL;
			TpTestsContactsConnection* _tmp40_ = NULL;
			TpHandle _tmp41_ = 0U;
			TpHandle* _tmp42_ = NULL;
			TpHandle* _tmp43_ = NULL;
			gint _tmp43__length1 = 0;
			const gchar* _tmp44_ = NULL;
			gchar* _tmp45_ = NULL;
			gchar** _tmp46_ = NULL;
			gchar** _tmp47_ = NULL;
			gint _tmp47__length1 = 0;
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp7_ = _i_it;
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp8_ = gee_iterator_next (_tmp7_);
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp8_) {
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2004 "individual-properties.c"
			}
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp9_ = _i_it;
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp10_ = gee_iterator_get (_tmp9_);
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp10_;
#line 277 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp11_ = i;
#line 277 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp11_ != NULL, "i != null");
#line 281 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp12_ = i;
#line 281 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp13_ = folks_individual_get_id (_tmp12_);
#line 281 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp14_ = _tmp13_;
#line 281 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (g_strcmp0 (_tmp14_, "0e46c5e74f61908f49550d241f2a1651892a1695") != 0) {
#line 283 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (i);
#line 283 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				continue;
#line 2028 "individual-properties.c"
			}
#line 287 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp15_ = i;
#line 287 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp16_ = folks_alias_details_get_alias ((FolksAliasDetails*) _tmp15_);
#line 287 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp17_ = _tmp16_;
#line 287 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp18_ = _data4_->new_alias;
#line 287 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (g_strcmp0 (_tmp17_, _tmp18_) != 0, "i.alias != new_alias");
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp19_ = i;
#line 289 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _tmp19_, "notify::alias", (GCallback) _____lambda6__g_object_notify, block4_data_ref (_data4_), (GClosureNotify) block4_data_unref, 0);
#line 300 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			persona = NULL;
#line 2046 "individual-properties.c"
			{
				GeeIterator* _p_it = NULL;
				FolksIndividual* _tmp20_ = NULL;
				GeeSet* _tmp21_ = NULL;
				GeeSet* _tmp22_ = NULL;
				GeeIterator* _tmp23_ = NULL;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp20_ = i;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp21_ = folks_individual_get_personas (_tmp20_);
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp22_ = _tmp21_;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_tmp23_ = gee_iterable_iterator ((GeeIterable*) _tmp22_);
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_p_it = _tmp23_;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 2065 "individual-properties.c"
					GeeIterator* _tmp24_ = NULL;
					gboolean _tmp25_ = FALSE;
					FolksPersona* p = NULL;
					GeeIterator* _tmp26_ = NULL;
					gpointer _tmp27_ = NULL;
					FolksPersona* _tmp28_ = NULL;
					FolksPersona* _tmp29_ = NULL;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp24_ = _p_it;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp25_ = gee_iterator_next (_tmp24_);
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (!_tmp25_) {
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						break;
#line 2081 "individual-properties.c"
					}
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp26_ = _p_it;
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp27_ = gee_iterator_get (_tmp26_);
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					p = (FolksPersona*) _tmp27_;
#line 303 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp28_ = p;
#line 303 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_tmp29_ = _g_object_ref0 (_tmp28_);
#line 303 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (persona);
#line 303 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					persona = _tmp29_;
#line 304 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (p);
#line 304 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					break;
#line 2101 "individual-properties.c"
				}
#line 301 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_p_it);
#line 2105 "individual-properties.c"
			}
#line 306 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp30_ = persona;
#line 306 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, TPF_TYPE_PERSONA), "persona is Tpf.Persona");
#line 310 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp31_ = persona;
#line 310 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp32_ = tpf_persona_get_contact (G_TYPE_CHECK_INSTANCE_CAST (_tmp31_, TPF_TYPE_PERSONA, TpfPersona));
#line 310 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp33_ = _tmp32_;
#line 310 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp34_ = tp_contact_get_handle (_tmp33_);
#line 310 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp35_ = _tmp34_;
#line 310 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			handle = (TpHandle) _tmp35_;
#line 311 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp36_ = ((TpfTestTestCase*) self)->tp_backend;
#line 311 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp37_ = ((TpfTestTestCase*) self)->account_handle;
#line 311 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp38_ = tp_tests_backend_get_connection_for_handle (_tmp36_, _tmp37_);
#line 311 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp39_ = _g_object_ref0 (_tmp38_);
#line 311 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			conn = _tmp39_;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp40_ = conn;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp41_ = handle;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp42_ = g_new0 (TpHandle, 1);
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp42_[0] = _tmp41_;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp43_ = _tmp42_;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp43__length1 = 1;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp44_ = _data4_->new_alias;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp45_ = g_strdup (_tmp44_);
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp46_ = g_new0 (gchar*, 1 + 1);
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp46_[0] = _tmp45_;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp47_ = _tmp46_;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp47__length1 = 1;
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			tp_tests_contacts_connection_change_aliases (_tmp40_, (guint) 1, _tmp43_, _tmp47_);
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp47_ = (_vala_array_free (_tmp47_, _tmp47__length1, (GDestroyNotify) g_free), NULL);
#line 312 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp43_ = (g_free (_tmp43_), NULL);
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (conn);
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (persona);
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 2169 "individual-properties.c"
		}
#line 275 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 2173 "individual-properties.c"
	}
#line 315 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp48_ = removed;
#line 315 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
#line 315 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp50_ = _tmp49_;
#line 315 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp50_ == 1, "removed.size == 1");
#line 2183 "individual-properties.c"
	{
		GeeIterator* _i_it = NULL;
		GeeSet* _tmp51_ = NULL;
		GeeIterator* _tmp52_ = NULL;
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp51_ = removed;
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp52_ = gee_iterable_iterator ((GeeIterable*) _tmp51_);
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_i_it = _tmp52_;
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 2196 "individual-properties.c"
			GeeIterator* _tmp53_ = NULL;
			gboolean _tmp54_ = FALSE;
			FolksIndividual* i = NULL;
			GeeIterator* _tmp55_ = NULL;
			gpointer _tmp56_ = NULL;
			FolksIndividual* _tmp57_ = NULL;
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp53_ = _i_it;
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp54_ = gee_iterator_next (_tmp53_);
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_tmp54_) {
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2211 "individual-properties.c"
			}
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp55_ = _i_it;
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp56_ = gee_iterator_get (_tmp55_);
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			i = (FolksIndividual*) _tmp56_;
#line 319 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_tmp57_ = i;
#line 319 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_tmp57_ == NULL, "i == null");
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (i);
#line 2225 "individual-properties.c"
		}
#line 317 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_i_it);
#line 2229 "individual-properties.c"
	}
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (removed);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (added);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	block4_data_unref (_data4_);
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data4_ = NULL;
#line 2239 "individual-properties.c"
}


static void ___lambda5__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	__lambda5_ (self, changes);
#line 2246 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_alias_through_test_cm (IndividualPropertiesTests* self) {
	Block3Data* _data3_;
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp1_ = NULL;
	FolksIndividualAggregator* _tmp2_ = NULL;
	FolksIndividualAggregator* _tmp3_ = NULL;
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data3_ = g_slice_new0 (Block3Data);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data3_->_ref_count_ = 1;
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data3_->self = g_object_ref (self);
#line 263 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 263 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 264 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data3_->alias_notified = FALSE;
#line 267 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = folks_individual_aggregator_dup ();
#line 267 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp1_;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = aggregator;
#line 268 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_data (_tmp2_, "individuals-changed-detailed", (GCallback) ___lambda5__folks_individual_aggregator_individuals_changed_detailed, block3_data_ref (_data3_), (GClosureNotify) block3_data_unref, 0);
#line 322 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = aggregator;
#line 322 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp3_, NULL, NULL);
#line 327 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 329 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data3_->alias_notified, "alias_notified");
#line 332 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 332 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	block3_data_unref (_data3_);
#line 261 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data3_ = NULL;
#line 2300 "individual-properties.c"
}


static void __lambda7_ (IndividualPropertiesTests* self, GeeMultiMap* changes) {
	GeeMultiMap* _tmp0_ = NULL;
#line 346 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (changes != NULL);
#line 348 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = changes;
#line 348 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added (self, _tmp0_, NULL, NULL);
#line 2312 "individual-properties.c"
}


static void ___lambda7__folks_individual_aggregator_individuals_changed_detailed (FolksIndividualAggregator* _sender, GeeMultiMap* changes, gpointer self) {
#line 346 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	__lambda7_ (self, changes);
#line 2319 "individual-properties.c"
}


void individual_properties_tests_test_individual_properties_change_contact_info (IndividualPropertiesTests* self) {
	GMainLoop* main_loop = NULL;
	GMainLoop* _tmp0_ = NULL;
	GeeHashSet* _tmp1_ = NULL;
	GeeHashSet* _tmp2_ = NULL;
	GeeHashSet* _tmp3_ = NULL;
	GeeHashSet* _tmp4_ = NULL;
	GeeHashSet* _tmp5_ = NULL;
	FolksIndividualAggregator* aggregator = NULL;
	FolksIndividualAggregator* _tmp6_ = NULL;
	FolksIndividualAggregator* _tmp7_ = NULL;
	FolksIndividualAggregator* _tmp8_ = NULL;
	GeeHashSet* _tmp9_ = NULL;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
#line 335 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (self != NULL);
#line 337 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = g_main_loop_new (NULL, FALSE);
#line 337 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	main_loop = _tmp0_;
#line 338 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = self->priv->_changes_pending;
#line 338 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp1_, "birthday");
#line 339 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = self->priv->_changes_pending;
#line 339 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp2_, "email-addresses");
#line 340 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = self->priv->_changes_pending;
#line 340 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp3_, "phone-numbers");
#line 341 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = self->priv->_changes_pending;
#line 341 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp4_, "full-name");
#line 342 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = self->priv->_changes_pending;
#line 342 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	gee_abstract_collection_add ((GeeAbstractCollection*) _tmp5_, "urls");
#line 345 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = folks_individual_aggregator_dup ();
#line 345 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = _tmp6_;
#line 346 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp7_ = aggregator;
#line 346 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_signal_connect_object (_tmp7_, "individuals-changed-detailed", (GCallback) ___lambda7__folks_individual_aggregator_individuals_changed_detailed, self, 0);
#line 351 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp8_ = aggregator;
#line 351 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_individual_aggregator_prepare (_tmp8_, NULL, NULL);
#line 356 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_utils_loop_run_with_non_fatal_timeout (main_loop, 3);
#line 358 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp9_ = self->priv->_changes_pending;
#line 358 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp10_ = gee_abstract_collection_get_size ((GeeCollection*) _tmp9_);
#line 358 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp11_ = _tmp10_;
#line 358 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_tmp11_ == 0, "this._changes_pending.size == 0");
#line 361 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 361 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	aggregator = NULL;
#line 335 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (aggregator);
#line 335 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_main_loop_unref0 (main_loop);
#line 2394 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free (gpointer _data) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
	_data_ = _data;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->changes);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->self);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_slice_free (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData, _data_);
#line 2407 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added (IndividualPropertiesTests* self, GeeMultiMap* changes, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
	IndividualPropertiesTests* _tmp0_ = NULL;
	GeeMultiMap* _tmp1_ = NULL;
	GeeMultiMap* _tmp2_ = NULL;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_ = g_slice_new0 (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, _individual_properties_tests_change_contact_info_aggregator_individuals_added);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_data_free);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->self = _tmp0_;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = changes;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->changes);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->changes = _tmp2_;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added_co (_data_);
#line 2436 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_finish (IndividualPropertiesTests* self, GAsyncResult* _res_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2444 "individual-properties.c"
}


static Block5Data* block5_data_ref (Block5Data* _data5_) {
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_atomic_int_inc (&_data5_->_ref_count_);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return _data5_;
#line 2453 "individual-properties.c"
}


static void block5_data_unref (void * _userdata_) {
	Block5Data* _data5_;
	_data5_ = (Block5Data*) _userdata_;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_atomic_int_dec_and_test (&_data5_->_ref_count_)) {
#line 2462 "individual-properties.c"
		IndividualPropertiesTests * self;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		self = _data5_->self;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_free0 (_data5_->new_full_name);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data5_->new_url_fd);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data5_->new_phone_fd);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data5_->new_email_fd);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_date_time_unref0 (_data5_->new_birthday);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (self);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_slice_free (Block5Data, _data5_);
#line 2480 "individual-properties.c"
	}
}


static void ____lambda8_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	gboolean _tmp3_ = FALSE;
	FolksIndividual* _tmp4_ = NULL;
	GDateTime* _tmp5_ = NULL;
	GDateTime* _tmp6_ = NULL;
	gboolean _tmp8_ = FALSE;
	gboolean _tmp14_ = FALSE;
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 398 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 398 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 398 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = ind;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp4_);
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = _tmp5_;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_ != NULL) {
#line 2517 "individual-properties.c"
		GDateTime* _tmp7_ = NULL;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = _data5_->new_birthday;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp3_ = _tmp7_ != NULL;
#line 2523 "individual-properties.c"
	} else {
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp3_ = FALSE;
#line 2527 "individual-properties.c"
	}
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp8_ = _tmp3_;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_tmp8_) {
#line 2533 "individual-properties.c"
		FolksIndividual* _tmp9_ = NULL;
		GDateTime* _tmp10_ = NULL;
		GDateTime* _tmp11_ = NULL;
		GDateTime* _tmp12_ = NULL;
		gboolean _tmp13_ = FALSE;
#line 401 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp9_ = ind;
#line 401 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp10_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _tmp9_);
#line 401 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp11_ = _tmp10_;
#line 401 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp12_ = _data5_->new_birthday;
#line 401 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp13_ = g_date_time_equal (_tmp11_, _tmp12_);
#line 401 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp2_ = _tmp13_;
#line 2551 "individual-properties.c"
	} else {
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp2_ = FALSE;
#line 2555 "individual-properties.c"
	}
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp14_ = _tmp2_;
#line 400 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_tmp14_) {
#line 2561 "individual-properties.c"
		GeeHashSet* _tmp15_ = NULL;
#line 403 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp15_ = self->priv->_changes_pending;
#line 403 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp15_, "birthday");
#line 2567 "individual-properties.c"
	}
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2571 "individual-properties.c"
}


static void _____lambda8__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda8_ (self, _sender, pspec);
#line 2578 "individual-properties.c"
}


static void ____lambda9_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	FolksEmailFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 410 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 410 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 410 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 412 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 412 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _tmp2_);
#line 412 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 412 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_email_fd;
#line 412 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 412 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2616 "individual-properties.c"
		GeeHashSet* _tmp7_ = NULL;
#line 414 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 414 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "email-addresses");
#line 2622 "individual-properties.c"
	}
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2626 "individual-properties.c"
}


static void _____lambda9__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda9_ (self, _sender, pspec);
#line 2633 "individual-properties.c"
}


static void ____lambda10_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 421 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 421 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 421 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 423 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 423 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_name_details_get_full_name ((FolksNameDetails*) _tmp2_);
#line 423 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 423 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_full_name;
#line 423 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (g_strcmp0 (_tmp4_, _tmp5_) == 0) {
#line 2668 "individual-properties.c"
		GeeHashSet* _tmp6_ = NULL;
#line 424 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp6_ = self->priv->_changes_pending;
#line 424 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp6_, "full-name");
#line 2674 "individual-properties.c"
	}
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2678 "individual-properties.c"
}


static void _____lambda10__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda10_ (self, _sender, pspec);
#line 2685 "individual-properties.c"
}


static void ____lambda11_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	FolksPhoneFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 430 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 430 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 430 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 432 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 432 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _tmp2_);
#line 432 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 432 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_phone_fd;
#line 432 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 432 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2723 "individual-properties.c"
		GeeHashSet* _tmp7_ = NULL;
#line 434 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 434 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "phone-numbers");
#line 2729 "individual-properties.c"
	}
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2733 "individual-properties.c"
}


static void _____lambda11__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda11_ (self, _sender, pspec);
#line 2740 "individual-properties.c"
}


static void ____lambda12_ (Block5Data* _data5_, GObject* s, GParamSpec* p) {
	IndividualPropertiesTests * self;
	FolksIndividual* ind = NULL;
	GObject* _tmp0_ = NULL;
	FolksIndividual* _tmp1_ = NULL;
	FolksIndividual* _tmp2_ = NULL;
	GeeSet* _tmp3_ = NULL;
	GeeSet* _tmp4_ = NULL;
	FolksUrlFieldDetails* _tmp5_ = NULL;
	gboolean _tmp6_ = FALSE;
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = _data5_->self;
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (s != NULL);
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_return_if_fail (p != NULL);
#line 441 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = s;
#line 441 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_CAST (_tmp0_, FOLKS_TYPE_INDIVIDUAL, FolksIndividual));
#line 441 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	ind = _tmp1_;
#line 443 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp2_ = ind;
#line 443 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp3_ = folks_url_details_get_urls ((FolksUrlDetails*) _tmp2_);
#line 443 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp4_ = _tmp3_;
#line 443 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp5_ = _data5_->new_url_fd;
#line 443 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp6_ = gee_collection_contains ((GeeCollection*) _tmp4_, _tmp5_);
#line 443 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_tmp6_) {
#line 2778 "individual-properties.c"
		GeeHashSet* _tmp7_ = NULL;
#line 445 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_tmp7_ = self->priv->_changes_pending;
#line 445 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		gee_abstract_collection_remove ((GeeAbstractCollection*) _tmp7_, "urls");
#line 2784 "individual-properties.c"
	}
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (ind);
#line 2788 "individual-properties.c"
}


static void _____lambda12__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	____lambda12_ (self, _sender, pspec);
#line 2795 "individual-properties.c"
}


static guint _folks_abstract_field_details_hash_static_gee_hash_data_func (gconstpointer v, gpointer self) {
	guint result;
	result = folks_abstract_field_details_hash_static (v);
#line 459 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2804 "individual-properties.c"
}


static gboolean _folks_abstract_field_details_equal_static_gee_equal_data_func (gconstpointer a, gconstpointer b, gpointer self) {
	gboolean result;
	result = folks_abstract_field_details_equal_static (a, b);
#line 459 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 2813 "individual-properties.c"
}


static void _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_ = _user_data_;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_source_object_ = source_object;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_res_ = _res_;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_individual_properties_tests_change_contact_info_aggregator_individuals_added_co (_data_);
#line 2827 "individual-properties.c"
}


static gboolean _individual_properties_tests_change_contact_info_aggregator_individuals_added_co (IndividualPropertiesTestsChangeContactInfoAggregatorIndividualsAddedData* _data_) {
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	switch (_data_->_state_) {
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		case 0:
#line 2836 "individual-properties.c"
		goto _state_0;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		case 1:
#line 2840 "individual-properties.c"
		goto _state_1;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		case 2:
#line 2844 "individual-properties.c"
		goto _state_2;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		case 3:
#line 2848 "individual-properties.c"
		goto _state_3;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		case 4:
#line 2852 "individual-properties.c"
		goto _state_4;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		case 5:
#line 2856 "individual-properties.c"
		goto _state_5;
		default:
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_assert_not_reached ();
#line 2861 "individual-properties.c"
	}
	_state_0:
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_ = g_slice_new0 (Block5Data);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->_ref_count_ = 1;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->self = g_object_ref (_data_->self);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->_async_data_ = _data_;
#line 367 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp0_ = NULL;
#line 367 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp0_ = _data_->changes;
#line 367 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp1_ = NULL;
#line 367 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp1_ = gee_multi_map_get_values (_data_->_tmp0_);
#line 367 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->added = _data_->_tmp1_;
#line 368 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp2_ = NULL;
#line 368 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp2_ = _data_->changes;
#line 368 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp3_ = NULL;
#line 368 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp3_ = gee_multi_map_get_keys (_data_->_tmp2_);
#line 368 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->removed = _data_->_tmp3_;
#line 370 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_get_current_time (&_data_->timeval);
#line 371 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_time_val_from_iso8601 ("1929-01-11T00:00:00Z", &_data_->timeval);
#line 372 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	memset (&_data_->_tmp4_, 0, sizeof (GTimeVal));
#line 372 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp4_ = _data_->timeval;
#line 372 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp5_ = NULL;
#line 372 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp5_ = g_date_time_new_from_timeval_utc (&_data_->_tmp4_);
#line 372 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_birthday = _data_->_tmp5_;
#line 373 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp6_ = NULL;
#line 373 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp6_ = folks_email_field_details_new ("cave@aperturescience.com", NULL);
#line 373 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_email_fd = _data_->_tmp6_;
#line 374 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp7_ = NULL;
#line 374 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp7_ = _data_->_data5_->new_email_fd;
#line 374 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp7_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_WORK);
#line 376 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp8_ = NULL;
#line 376 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp8_ = folks_phone_field_details_new ("+112233445566", NULL);
#line 376 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_phone_fd = _data_->_tmp8_;
#line 377 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp9_ = NULL;
#line 377 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp9_ = _data_->_data5_->new_phone_fd;
#line 377 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp9_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_HOME);
#line 379 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp10_ = NULL;
#line 379 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp10_ = folks_url_field_details_new ("aperturescience.com/cave", NULL);
#line 379 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_url_fd = _data_->_tmp10_;
#line 380 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp11_ = NULL;
#line 380 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp11_ = _data_->_data5_->new_url_fd;
#line 380 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_abstract_field_details_set_parameter ((FolksAbstractFieldDetails*) _data_->_tmp11_, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE, FOLKS_ABSTRACT_FIELD_DETAILS_PARAM_TYPE_WORK);
#line 382 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp12_ = NULL;
#line 382 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp12_ = g_strdup ("Cave Johnson");
#line 382 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_->new_full_name = _data_->_tmp12_;
#line 2948 "individual-properties.c"
	{
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp13_ = NULL;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp13_ = _data_->added;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp14_ = NULL;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp14_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp13_);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_i_it = _data_->_tmp14_;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp15_ = NULL;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp15_ = _data_->_i_it;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp16_ = FALSE;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp16_ = gee_iterator_next (_data_->_tmp15_);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp16_) {
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 2974 "individual-properties.c"
			}
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp17_ = NULL;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp17_ = _data_->_i_it;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp18_ = NULL;
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp18_ = gee_iterator_get (_data_->_tmp17_);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->i = (FolksIndividual*) _data_->_tmp18_;
#line 386 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp19_ = NULL;
#line 386 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp19_ = _data_->i;
#line 386 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_data_->_tmp19_ != NULL, "i != null");
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp21_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp21_ = _data_->i;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp22_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp22_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp21_);
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp23_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp23_ = _data_->_tmp22_;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_tmp23_ == NULL) {
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp20_ = TRUE;
#line 3008 "individual-properties.c"
			} else {
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp24_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp24_ = _data_->_data5_->new_birthday;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp25_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp25_ = _data_->i;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp26_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp26_ = folks_birthday_details_get_birthday ((FolksBirthdayDetails*) _data_->_tmp25_);
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp27_ = NULL;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp27_ = _data_->_tmp26_;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp28_ = FALSE;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp28_ = g_date_time_equal (_data_->_tmp24_, _data_->_tmp27_);
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp20_ = !_data_->_tmp28_;
#line 3032 "individual-properties.c"
			}
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp29_ = FALSE;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp29_ = _data_->_tmp20_;
#line 389 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_data_->_tmp29_, "i.birthday == null || !new_birthday.equal (i.birthday)");
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp30_ = NULL;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp30_ = _data_->i;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp31_ = NULL;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp31_ = folks_email_details_get_email_addresses ((FolksEmailDetails*) _data_->_tmp30_);
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp32_ = NULL;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp32_ = _data_->_tmp31_;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp33_ = NULL;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp33_ = _data_->_data5_->new_email_fd;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp34_ = FALSE;
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp34_ = gee_collection_contains ((GeeCollection*) _data_->_tmp32_, _data_->_tmp33_);
#line 390 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (!_data_->_tmp34_, "!(new_email_fd in i.email_addresses)");
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp35_ = NULL;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp35_ = _data_->_data5_->new_full_name;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp36_ = NULL;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp36_ = _data_->i;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp37_ = NULL;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp37_ = folks_name_details_get_full_name ((FolksNameDetails*) _data_->_tmp36_);
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp38_ = NULL;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp38_ = _data_->_tmp37_;
#line 391 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (g_strcmp0 (_data_->_tmp35_, _data_->_tmp38_) != 0, "new_full_name != i.full_name");
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp39_ = NULL;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp39_ = _data_->i;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp40_ = NULL;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp40_ = folks_phone_details_get_phone_numbers ((FolksPhoneDetails*) _data_->_tmp39_);
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp41_ = NULL;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp41_ = _data_->_tmp40_;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp42_ = NULL;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp42_ = _data_->_data5_->new_phone_fd;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp43_ = FALSE;
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp43_ = gee_collection_contains ((GeeCollection*) _data_->_tmp41_, _data_->_tmp42_);
#line 392 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (!_data_->_tmp43_, "!(new_phone_fd in i.phone_numbers)");
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp44_ = NULL;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp44_ = _data_->i;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp45_ = NULL;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp45_ = folks_url_details_get_urls ((FolksUrlDetails*) _data_->_tmp44_);
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp46_ = NULL;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp46_ = _data_->_tmp45_;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp47_ = NULL;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp47_ = _data_->_data5_->new_url_fd;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp48_ = FALSE;
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp48_ = gee_collection_contains ((GeeCollection*) _data_->_tmp46_, _data_->_tmp47_);
#line 393 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (!_data_->_tmp48_, "!(new_url_fd in i.urls)");
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp49_ = NULL;
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp49_ = _data_->i;
#line 395 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp49_, "notify::birthday", (GCallback) _____lambda8__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp50_ = NULL;
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp50_ = _data_->i;
#line 407 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp50_, "notify::email-addresses", (GCallback) _____lambda9__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp51_ = NULL;
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp51_ = _data_->i;
#line 418 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp51_, "notify::full-name", (GCallback) _____lambda10__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp52_ = NULL;
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp52_ = _data_->i;
#line 427 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp52_, "notify::phone-numbers", (GCallback) _____lambda11__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp53_ = NULL;
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp53_ = _data_->i;
#line 438 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			g_signal_connect_data ((GObject*) _data_->_tmp53_, "notify::urls", (GCallback) _____lambda12__g_object_notify, block5_data_ref (_data_->_data5_), (GClosureNotify) block5_data_unref, 0);
#line 451 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->persona = NULL;
#line 3156 "individual-properties.c"
			{
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp54_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp54_ = _data_->i;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp55_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp55_ = folks_individual_get_personas (_data_->_tmp54_);
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp56_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp56_ = _data_->_tmp55_;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp57_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp57_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp56_);
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_p_it = _data_->_tmp57_;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				while (TRUE) {
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp58_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp58_ = _data_->_p_it;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp59_ = FALSE;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp59_ = gee_iterator_next (_data_->_tmp58_);
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (!_data_->_tmp59_) {
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
						break;
#line 3190 "individual-properties.c"
					}
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp60_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp60_ = _data_->_p_it;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp61_ = NULL;
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp61_ = gee_iterator_get (_data_->_tmp60_);
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->p = (FolksPersona*) _data_->_tmp61_;
#line 454 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp62_ = NULL;
#line 454 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp62_ = _data_->p;
#line 454 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp63_ = NULL;
#line 454 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp63_ = _g_object_ref0 (_data_->_tmp62_);
#line 454 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 454 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->persona = _data_->_tmp63_;
#line 455 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->p);
#line 455 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					break;
#line 3218 "individual-properties.c"
				}
#line 452 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_p_it);
#line 3222 "individual-properties.c"
			}
#line 457 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp64_ = NULL;
#line 457 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp64_ = _data_->persona;
#line 457 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (G_TYPE_CHECK_INSTANCE_TYPE (_data_->_tmp64_, TPF_TYPE_PERSONA), "persona is Tpf.Persona");
#line 459 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp65_ = NULL;
#line 459 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp65_ = gee_hash_set_new (FOLKS_TYPE_EMAIL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 459 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->emails = _data_->_tmp65_;
#line 462 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp66_ = NULL;
#line 462 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp66_ = _data_->emails;
#line 462 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp67_ = NULL;
#line 462 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp67_ = _data_->_data5_->new_email_fd;
#line 462 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp66_, _data_->_tmp67_);
#line 463 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp68_ = NULL;
#line 463 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp68_ = gee_hash_set_new (FOLKS_TYPE_PHONE_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 463 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->phones = _data_->_tmp68_;
#line 466 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp69_ = NULL;
#line 466 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp69_ = _data_->phones;
#line 466 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp70_ = NULL;
#line 466 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp70_ = _data_->_data5_->new_phone_fd;
#line 466 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp69_, _data_->_tmp70_);
#line 467 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp71_ = NULL;
#line 467 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp71_ = gee_hash_set_new (FOLKS_TYPE_URL_FIELD_DETAILS, (GBoxedCopyFunc) g_object_ref, g_object_unref, _folks_abstract_field_details_hash_static_gee_hash_data_func, NULL, NULL, _folks_abstract_field_details_equal_static_gee_equal_data_func, NULL, NULL);
#line 467 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->urls = _data_->_tmp71_;
#line 470 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp72_ = NULL;
#line 470 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp72_ = _data_->urls;
#line 470 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp73_ = NULL;
#line 470 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp73_ = _data_->_data5_->new_url_fd;
#line 470 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			gee_abstract_collection_add ((GeeAbstractCollection*) _data_->_tmp72_, _data_->_tmp73_);
#line 478 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->uncaught_errors = 0;
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp74_ = NULL;
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp74_ = _data_->i;
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp75_ = FALSE;
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp75_ = folks_individual_get_is_user (_data_->_tmp74_);
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp76_ = FALSE;
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp76_ = _data_->_tmp75_;
#line 480 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp76_) {
#line 481 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp77_ = 0;
#line 481 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp77_ = _data_->uncaught_errors;
#line 481 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp77_ + 1;
#line 3300 "individual-properties.c"
			}
			{
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp78_ = NULL;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp78_ = _data_->persona;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp79_ = NULL;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp79_ = _data_->_data5_->new_birthday;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 1;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_birthday_details_change_birthday ((FolksBirthdayDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp78_, TPF_TYPE_PERSONA, TpfPersona), _data_->_tmp79_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3317 "individual-properties.c"
				_state_1:
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_birthday_details_change_birthday_finish ((FolksBirthdayDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp78_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3325 "individual-properties.c"
						goto __catch0_folks_property_error;
					}
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 484 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3354 "individual-properties.c"
				}
			}
			goto __finally0;
			__catch0_folks_property_error:
			{
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->e_birthday = _data_->_inner_error_;
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp80_ = NULL;
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp80_ = _data_->i;
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp81_ = FALSE;
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp81_ = folks_individual_get_is_user (_data_->_tmp80_);
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp82_ = FALSE;
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp82_ = _data_->_tmp81_;
#line 488 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp82_) {
#line 489 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp83_ = 0;
#line 489 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp83_ = _data_->uncaught_errors;
#line 489 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp83_ - 1;
#line 3384 "individual-properties.c"
				}
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e_birthday);
#line 3388 "individual-properties.c"
			}
			__finally0:
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 482 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3419 "individual-properties.c"
			}
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp84_ = NULL;
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp84_ = _data_->i;
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp85_ = FALSE;
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp85_ = folks_individual_get_is_user (_data_->_tmp84_);
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp86_ = FALSE;
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp86_ = _data_->_tmp85_;
#line 492 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp86_) {
#line 493 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp87_ = 0;
#line 493 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp87_ = _data_->uncaught_errors;
#line 493 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp87_ + 1;
#line 3441 "individual-properties.c"
			}
			{
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp88_ = NULL;
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp88_ = _data_->persona;
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp89_ = NULL;
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp89_ = _data_->emails;
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 2;
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_email_details_change_email_addresses ((FolksEmailDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp88_, TPF_TYPE_PERSONA, TpfPersona), (GeeSet*) _data_->_tmp89_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3458 "individual-properties.c"
				_state_2:
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_email_details_change_email_addresses_finish ((FolksEmailDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp88_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3466 "individual-properties.c"
						goto __catch1_folks_property_error;
					}
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 496 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3495 "individual-properties.c"
				}
			}
			goto __finally1;
			__catch1_folks_property_error:
			{
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->e0 = _data_->_inner_error_;
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp90_ = NULL;
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp90_ = _data_->i;
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp91_ = FALSE;
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp91_ = folks_individual_get_is_user (_data_->_tmp90_);
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp92_ = FALSE;
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp92_ = _data_->_tmp91_;
#line 502 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp92_) {
#line 503 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp93_ = 0;
#line 503 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp93_ = _data_->uncaught_errors;
#line 503 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp93_ - 1;
#line 3525 "individual-properties.c"
				}
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e0);
#line 3529 "individual-properties.c"
			}
			__finally1:
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 494 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3560 "individual-properties.c"
			}
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp94_ = NULL;
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp94_ = _data_->i;
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp95_ = FALSE;
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp95_ = folks_individual_get_is_user (_data_->_tmp94_);
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp96_ = FALSE;
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp96_ = _data_->_tmp95_;
#line 506 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp96_) {
#line 507 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp97_ = 0;
#line 507 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp97_ = _data_->uncaught_errors;
#line 507 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp97_ + 1;
#line 3582 "individual-properties.c"
			}
			{
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp98_ = NULL;
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp98_ = _data_->persona;
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp99_ = NULL;
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp99_ = _data_->_data5_->new_full_name;
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 3;
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_name_details_change_full_name ((FolksNameDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp98_, TPF_TYPE_PERSONA, TpfPersona), _data_->_tmp99_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3599 "individual-properties.c"
				_state_3:
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_name_details_change_full_name_finish ((FolksNameDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp98_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3607 "individual-properties.c"
						goto __catch2_folks_property_error;
					}
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 510 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3636 "individual-properties.c"
				}
			}
			goto __finally2;
			__catch2_folks_property_error:
			{
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->e1 = _data_->_inner_error_;
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp100_ = NULL;
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp100_ = _data_->i;
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp101_ = FALSE;
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp101_ = folks_individual_get_is_user (_data_->_tmp100_);
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp102_ = FALSE;
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp102_ = _data_->_tmp101_;
#line 514 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp102_) {
#line 515 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp103_ = 0;
#line 515 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp103_ = _data_->uncaught_errors;
#line 515 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp103_ - 1;
#line 3666 "individual-properties.c"
				}
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e1);
#line 3670 "individual-properties.c"
			}
			__finally2:
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 508 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3701 "individual-properties.c"
			}
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp104_ = NULL;
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp104_ = _data_->i;
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp105_ = FALSE;
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp105_ = folks_individual_get_is_user (_data_->_tmp104_);
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp106_ = FALSE;
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp106_ = _data_->_tmp105_;
#line 518 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp106_) {
#line 519 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp107_ = 0;
#line 519 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp107_ = _data_->uncaught_errors;
#line 519 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp107_ + 1;
#line 3723 "individual-properties.c"
			}
			{
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp108_ = NULL;
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp108_ = _data_->persona;
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp109_ = NULL;
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp109_ = _data_->phones;
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 4;
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_phone_details_change_phone_numbers ((FolksPhoneDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp108_, TPF_TYPE_PERSONA, TpfPersona), (GeeSet*) _data_->_tmp109_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3740 "individual-properties.c"
				_state_4:
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_phone_details_change_phone_numbers_finish ((FolksPhoneDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp108_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3748 "individual-properties.c"
						goto __catch3_folks_property_error;
					}
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 522 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3777 "individual-properties.c"
				}
			}
			goto __finally3;
			__catch3_folks_property_error:
			{
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->e2 = _data_->_inner_error_;
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp110_ = NULL;
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp110_ = _data_->i;
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp111_ = FALSE;
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp111_ = folks_individual_get_is_user (_data_->_tmp110_);
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp112_ = FALSE;
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp112_ = _data_->_tmp111_;
#line 528 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp112_) {
#line 529 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp113_ = 0;
#line 529 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp113_ = _data_->uncaught_errors;
#line 529 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp113_ - 1;
#line 3807 "individual-properties.c"
				}
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e2);
#line 3811 "individual-properties.c"
			}
			__finally3:
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 520 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3842 "individual-properties.c"
			}
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp114_ = NULL;
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp114_ = _data_->i;
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp115_ = FALSE;
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp115_ = folks_individual_get_is_user (_data_->_tmp114_);
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp116_ = FALSE;
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp116_ = _data_->_tmp115_;
#line 532 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp116_) {
#line 533 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp117_ = 0;
#line 533 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp117_ = _data_->uncaught_errors;
#line 533 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->uncaught_errors = _data_->_tmp117_ + 1;
#line 3864 "individual-properties.c"
			}
			{
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp118_ = NULL;
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp118_ = _data_->persona;
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp119_ = NULL;
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp119_ = _data_->urls;
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_state_ = 5;
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_url_details_change_urls ((FolksUrlDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp118_, TPF_TYPE_PERSONA, TpfPersona), (GeeSet*) _data_->_tmp119_, _individual_properties_tests_change_contact_info_aggregator_individuals_added_ready, _data_);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3881 "individual-properties.c"
				_state_5:
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				folks_url_details_change_urls_finish ((FolksUrlDetails*) G_TYPE_CHECK_INSTANCE_CAST (_data_->_tmp118_, TPF_TYPE_PERSONA, TpfPersona), _data_->_res_, &_data_->_inner_error_);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (_data_->_inner_error_ != NULL) {
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					if (_data_->_inner_error_->domain == FOLKS_PROPERTY_ERROR) {
#line 3889 "individual-properties.c"
						goto __catch4_folks_property_error;
					}
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->urls);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->phones);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->emails);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->persona);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->i);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->_i_it);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->removed);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_g_object_unref0 (_data_->added);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					block5_data_unref (_data_->_data5_);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_data5_ = NULL;
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					g_clear_error (&_data_->_inner_error_);
#line 536 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					return FALSE;
#line 3918 "individual-properties.c"
				}
			}
			goto __finally4;
			__catch4_folks_property_error:
			{
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->e3 = _data_->_inner_error_;
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_inner_error_ = NULL;
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp120_ = NULL;
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp120_ = _data_->i;
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp121_ = FALSE;
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp121_ = folks_individual_get_is_user (_data_->_tmp120_);
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp122_ = FALSE;
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp122_ = _data_->_tmp121_;
#line 542 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				if (!_data_->_tmp122_) {
#line 543 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp123_ = 0;
#line 543 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->_tmp123_ = _data_->uncaught_errors;
#line 543 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
					_data_->uncaught_errors = _data_->_tmp123_ - 1;
#line 3948 "individual-properties.c"
				}
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_error_free0 (_data_->e3);
#line 3952 "individual-properties.c"
			}
			__finally4:
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (_data_->_inner_error_ != NULL) {
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->urls);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->phones);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->emails);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->persona);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->i);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->_i_it);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->removed);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_g_object_unref0 (_data_->added);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				block5_data_unref (_data_->_data5_);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_data5_ = NULL;
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				g_clear_error (&_data_->_inner_error_);
#line 534 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				return FALSE;
#line 3983 "individual-properties.c"
			}
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp124_ = NULL;
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp124_ = _data_->i;
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp125_ = FALSE;
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp125_ = folks_individual_get_is_user (_data_->_tmp124_);
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp126_ = FALSE;
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp126_ = _data_->_tmp125_;
#line 546 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp126_) {
#line 548 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp127_ = 0;
#line 548 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_data_->_tmp127_ = _data_->uncaught_errors;
#line 548 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				_vala_assert (_data_->_tmp127_ == 0, "uncaught_errors == 0");
#line 4005 "individual-properties.c"
			}
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->urls);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->phones);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->emails);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->persona);
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->i);
#line 4017 "individual-properties.c"
		}
#line 384 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data_->_i_it);
#line 4021 "individual-properties.c"
	}
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp128_ = NULL;
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp128_ = _data_->removed;
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp129_ = 0;
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp129_ = gee_collection_get_size ((GeeCollection*) _data_->_tmp128_);
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp130_ = 0;
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_tmp130_ = _data_->_tmp129_;
#line 552 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_vala_assert (_data_->_tmp130_ == 1, "removed.size == 1");
#line 4037 "individual-properties.c"
	{
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp131_ = NULL;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp131_ = _data_->removed;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp132_ = NULL;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_tmp132_ = gee_iterable_iterator ((GeeIterable*) _data_->_tmp131_);
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_data_->_r_it = _data_->_tmp132_;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		while (TRUE) {
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp133_ = NULL;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp133_ = _data_->_r_it;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp134_ = FALSE;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp134_ = gee_iterator_next (_data_->_tmp133_);
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			if (!_data_->_tmp134_) {
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
				break;
#line 4063 "individual-properties.c"
			}
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp135_ = NULL;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp135_ = _data_->_r_it;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp136_ = NULL;
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp136_ = gee_iterator_get (_data_->_tmp135_);
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->r = (FolksIndividual*) _data_->_tmp136_;
#line 556 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp137_ = NULL;
#line 556 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_data_->_tmp137_ = _data_->r;
#line 556 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_vala_assert (_data_->_tmp137_ == NULL, "r == null");
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
			_g_object_unref0 (_data_->r);
#line 4083 "individual-properties.c"
		}
#line 554 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		_g_object_unref0 (_data_->_r_it);
#line 4087 "individual-properties.c"
	}
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->removed);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (_data_->added);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	block5_data_unref (_data_->_data5_);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_data_->_data5_ = NULL;
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	if (_data_->_state_ == 0) {
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4101 "individual-properties.c"
	} else {
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4105 "individual-properties.c"
	}
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_object_unref (_data_->_async_result);
#line 364 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return FALSE;
#line 4111 "individual-properties.c"
}


static void individual_properties_tests_class_init (IndividualPropertiesTestsClass * klass) {
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	individual_properties_tests_parent_class = g_type_class_peek_parent (klass);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_type_class_add_private (klass, sizeof (IndividualPropertiesTestsPrivate));
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (klass)->set_up = individual_properties_tests_real_set_up;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	FOLKS_TEST_CASE_CLASS (klass)->tear_down = individual_properties_tests_real_tear_down;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	G_OBJECT_CLASS (klass)->finalize = individual_properties_tests_finalize;
#line 4126 "individual-properties.c"
}


static void individual_properties_tests_instance_init (IndividualPropertiesTests * self) {
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self->priv = INDIVIDUAL_PROPERTIES_TESTS_GET_PRIVATE (self);
#line 29 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self->priv->_changes_pending = NULL;
#line 4135 "individual-properties.c"
}


static void individual_properties_tests_finalize (GObject* obj) {
	IndividualPropertiesTests * self;
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TYPE_INDIVIDUAL_PROPERTIES_TESTS, IndividualPropertiesTests);
#line 29 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (self->priv->_changes_pending);
#line 27 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	G_OBJECT_CLASS (individual_properties_tests_parent_class)->finalize (obj);
#line 4147 "individual-properties.c"
}


GType individual_properties_tests_get_type (void) {
	static volatile gsize individual_properties_tests_type_id__volatile = 0;
	if (g_once_init_enter (&individual_properties_tests_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (IndividualPropertiesTestsClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) individual_properties_tests_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (IndividualPropertiesTests), 0, (GInstanceInitFunc) individual_properties_tests_instance_init, NULL };
		GType individual_properties_tests_type_id;
		individual_properties_tests_type_id = g_type_register_static (TPF_TEST_TYPE_TEST_CASE, "IndividualPropertiesTests", &g_define_type_info, 0);
		g_once_init_leave (&individual_properties_tests_type_id__volatile, individual_properties_tests_type_id);
	}
	return individual_properties_tests_type_id__volatile;
}


gint _vala_main (gchar** args, int args_length1) {
	gint result = 0;
	IndividualPropertiesTests* tests = NULL;
	IndividualPropertiesTests* _tmp0_ = NULL;
#line 563 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_test_init (&args_length1, &args, NULL);
#line 565 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_tmp0_ = individual_properties_tests_new ();
#line 565 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	tests = _tmp0_;
#line 566 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_register ((FolksTestCase*) tests);
#line 567 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_test_run ();
#line 568 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	folks_test_case_final_tear_down ((FolksTestCase*) tests);
#line 570 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	result = 0;
#line 570 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	_g_object_unref0 (tests);
#line 570 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return result;
#line 4185 "individual-properties.c"
}


int main (int argc, char ** argv) {
#line 561 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	g_type_init ();
#line 561 "/home/treitter/collabora/folks/tests/telepathy/individual-properties.vala"
	return _vala_main (argv, argc);
#line 4194 "individual-properties.c"
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}



